==> spip_4.0.4.orig.tar.xz: plugins-dist/forum/lang/forum_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=ast
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'sólo pa los artículos futuros (ensin actuar so la base de datos).',
	'bouton_radio_articles_tous' => 'pa tolos artículos ensin esceición.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'pa tolos artículos, menos los que tengan el foru desactiváu.',
	'bouton_radio_enregistrement_obligatoire' => 'Rexistru obligatoriu (los usuarios
  tienen que abonase coles sos señes d’e-mail enantes
  de que puedan escribir les sos contribuciones).',
	'bouton_radio_moderation_priori' => 'Moderación a priori (les contribuciones
 nun apaecerán en públicu hasta que les validen
 los alministradores).', # MODIF
	'bouton_radio_modere_abonnement' => 'pa abonáos',
	'bouton_radio_modere_posteriori' => 'moderación a posteriori',
	'bouton_radio_modere_priori' => 'moderación a priori',
	'bouton_radio_publication_immediate' => 'Espublizar d’inmediatu los mensaxes
 (les contribuciones s’amuesen desque s’unvíen, los alministradores pueden
 desaniciales llueu).',

	// D
	'documents_interdits_forum' => 'Documentos torgaos nel foru',

	// F
	'form_pet_message_commentaire' => '¿Un mensaxe, un comentariu?',
	'forum' => 'Foru',
	'forum_acces_refuse' => 'Ya nun ties accesu a estos foros.',
	'forum_attention_dix_caracteres' => '<b>¡Atención!</b> el mensaxe tien que tener polo menos diez carauteres.',
	'forum_attention_trois_caracteres' => '<b>¡Atención!</b> el títulu tien que tener polo menos tres carauteres.',
	'forum_attention_trop_caracteres' => '<b>¡Atención!</b> esti mensaxe ye enforma llargu (@compte@ carauteres): pa que pueda rexistrase, nun tien que pasar de @max@ carauteres.', # MODIF
	'forum_avez_selectionne' => 'Seleicionasti:',
	'forum_cliquer_retour' => 'Calca <a href=\'@retour_forum@\'>equí</a> pa continuar.',
	'forum_forum' => 'foru',
	'forum_info_modere' => 'Esti foru ta llendáu de mano: la to aportación nun va apaecer fasta qu’un alministrador del sitiu nun-y de el preste.', # MODIF
	'forum_lien_hyper' => '<b>Enllace d’hipertestu</b> (opcional)', # MODIF
	'forum_message_definitif' => 'Mensaxe definitivu: unviar al sitiu',
	'forum_message_trop_long' => 'El to mensaxe ye enforma llargu. El tamañu másimu ye de 20000 carauteres.', # MODIF
	'forum_ne_repondez_pas' => 'Nun responder a esti corréu sinón nel foru, nes señes darréu:',
	'forum_page_url' => '(Si el to mensaxe refierse a un artículu espublizáu na Rede, o a una páxina que tenga más información, equí embaxo vas poder indicar el títulu de la páxina y les sos señes.)',
	'forum_poste_par' => 'Mensaxe unviáu @parauteur@ tocante a l’artículu «@titre@».', # MODIF
	'forum_qui_etes_vous' => '<b>¿Quién yes?</b> (opcional)', # MODIF
	'forum_texte' => 'Testu del to mensaxe:', # MODIF
	'forum_titre' => 'Títulu',
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar la escoyeta',
	'forum_voir_avant' => 'Ver el mensaxe enantes de publicalu', # MODIF
	'forum_votre_email' => 'Les tos señes d’email:', # MODIF
	'forum_votre_nom' => 'El to nome (o nomatu):', # MODIF
	'forum_vous_enregistrer' => 'Pa poder participar nesti
  foru, primero hai que rexistrase.
  Escribe embaxo l’identificador personal que
  recibisti. Si nun tas rexistráu, ties que',
	'forum_vous_inscrire' => 'inscribite.',

	// I
	'icone_poster_message' => 'Unviar un mensaxe',
	'icone_suivi_forum' => 'Siguimientu del foru públicu: @nb_forums@ contribución(es)',
	'icone_suivi_forums' => 'Siguir/xestionar los foros',
	'icone_supprimer_message' => 'Desaniciar esti mensaxe',
	'icone_valider_message' => 'Validar esti mensaxe',
	'info_activer_forum_public' => '<i>Pa activar los foros públicos, has d’escoyer el tipu
 de moderación por omisión:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar esta escoyeta pal llendamientu:',
	'info_config_forums_prive' => 'Nel espaciu priváu del sitiu, puedes activar dellos tipos de foros:', # MODIF
	'info_config_forums_prive_admin' => 'Un foru acutáu pa los alministradores del sitiu:',
	'info_config_forums_prive_global' => 'Un foru global, abiertu pa tolos redactores:',
	'info_config_forums_prive_objets' => 'Un foru pa cada artículu, breve, sitiu referenciáu, etc.:',
	'info_desactiver_forum_public' => 'Desactivar l’usu de los foros publicos.
 Los foros públicos podrán autorizase casu por casu
 pa los artículos; pero tarán torgaos pa les estayes, breves, etc.',
	'info_envoi_forum' => 'Unvíu de los foros a los autores de los artículos',
	'info_fonctionnement_forum' => 'Funcionamientu del foru:',
	'info_gauche_suivi_forum_2' => 'La páxina de <i>siguimientu de los foros</i> ye una ferramienta de xestión del sitiu Web (y non un espaciu pal discutiniu o la redaición). Amuesa toles contribuciones de los foros del sitiu, lo mesmo de la parte pública que del espaciu priváu y te permite remanar eses contribuciones.', # MODIF
	'info_liens_syndiques_3' => 'foros',
	'info_liens_syndiques_4' => 'tan',
	'info_liens_syndiques_5' => 'foru',
	'info_liens_syndiques_6' => 'ta',
	'info_liens_syndiques_7' => 'esperando pola validación',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mou de funcionamientu por omisión de los foros públicos',
	'info_option_email' => 'Cuando un visitante del sitiu unvía un mensaxe nuevu al foru venceyáu a un artículu, puede avisase a los o les autores del mesmu por e-mail. Escoyer pa cada tipu de foru si va emplegase esta opción.',
	'info_pas_de_forum' => 'ensin foru',
	'info_question_visiteur_ajout_document_forum' => 'Si quiés autorizar que los visitantes amesten documentos (imáxenes, sones...) nos sos mensaxes del foru, indica embaxo la llista d’estensiones de documentu permitíes nos foros (p. ex: gif, jpg, png, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Si quiés autorizar tolos tipos de documentu que SPIP considera fiables, pon un asteriscu. Pa nun autorizar na, déxalo en blancu,', # MODIF
	'item_activer_forum_administrateur' => 'Activar el foru de los alministradores',
	'item_config_forums_prive_global' => 'Activar el foru de los redactores',
	'item_config_forums_prive_objets' => 'Activar estos foros',
	'item_desactiver_forum_administrateur' => 'Desactivar el foru de los alministradores',
	'item_non_config_forums_prive_global' => 'Desactivar el foru de los redactores',
	'item_non_config_forums_prive_objets' => 'Desactivar estos foros',

	// L
	'lien_reponse_article' => 'Respuesta a l’artículu',
	'lien_reponse_breve_2' => 'Respuesta a la breve',
	'lien_reponse_rubrique' => 'Respuesta a la estaya',
	'lien_reponse_site_reference' => 'Respuesta al sitiu referenciáu:', # MODIF

	// O
	'onglet_messages_internes' => 'Mensaxes internos',
	'onglet_messages_publics' => 'Mensaxes públicos',
	'onglet_messages_vide' => 'Mensaxes ensin testu',

	// R
	'repondre_message' => 'Responder a esti mensaxe',

	// S
	'statut_original' => 'orixinal',

	// T
	'text_article_propose_publication_forum' => 'Encamentamoste a dar la to opinión nel foru axuntu a esti artículu (embaxo de la páxina).',
	'texte_en_cours_validation_forum' => 'Encamentámoste que opines usando los foros que tien xuníos.',
	'titre_cadre_forum_administrateur' => 'Foru privau de los alministradores',
	'titre_cadre_forum_interne' => 'Foru internu',
	'titre_config_forums_prive' => 'Foros de l’espaciu priváu',
	'titre_forum' => 'Foru',
	'titre_forum_suivi' => 'Siguir foros',
	'titre_page_forum_suivi' => 'Siguir los foros'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=ast
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'sólo pa los artículos futuros (ensin actuar so la base de datos).',
	'bouton_radio_articles_tous' => 'pa tolos artículos ensin esceición.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'pa tolos artículos, menos los que tengan el foru desactiváu.',
	'bouton_radio_enregistrement_obligatoire' => 'Rexistru obligatoriu (los usuarios
  tienen que abonase coles sos señes d’e-mail enantes
  de que puedan escribir les sos contribuciones).',
	'bouton_radio_moderation_priori' => 'Moderación a priori (les contribuciones
 nun apaecerán en públicu hasta que les validen
 los alministradores).', # MODIF
	'bouton_radio_modere_abonnement' => 'pa abonáos',
	'bouton_radio_modere_posteriori' => 'moderación a posteriori',
	'bouton_radio_modere_priori' => 'moderación a priori',
	'bouton_radio_publication_immediate' => 'Espublizar d’inmediatu los mensaxes
 (les contribuciones s’amuesen desque s’unvíen, los alministradores pueden
 desaniciales llueu).',

	// D
	'documents_interdits_forum' => 'Documentos torgaos nel foru',

	// F
	'form_pet_message_commentaire' => '¿Un mensaxe, un comentariu?',
	'forum' => 'Foru',
	'forum_acces_refuse' => 'Ya nun ties accesu a estos foros.',
	'forum_attention_dix_caracteres' => '<b>¡Atención!</b> el mensaxe tien que tener polo menos diez carauteres.',
	'forum_attention_trois_caracteres' => '<b>¡Atención!</b> el títulu tien que tener polo menos tres carauteres.',
	'forum_attention_trop_caracteres' => '<b>¡Atención!</b> esti mensaxe ye enforma llargu (@compte@ carauteres): pa que pueda rexistrase, nun tien que pasar de @max@ carauteres.', # MODIF
	'forum_avez_selectionne' => 'Seleicionasti:',
	'forum_cliquer_retour' => 'Calca <a href=\'@retour_forum@\'>equí</a> pa continuar.',
	'forum_forum' => 'foru',
	'forum_info_modere' => 'Esti foru ta llendáu de mano: la to aportación nun va apaecer fasta qu’un alministrador del sitiu nun-y de el preste.', # MODIF
	'forum_lien_hyper' => '<b>Enllace d’hipertestu</b> (opcional)', # MODIF
	'forum_message_definitif' => 'Mensaxe definitivu: unviar al sitiu',
	'forum_message_trop_long' => 'El to mensaxe ye enforma llargu. El tamañu másimu ye de 20000 carauteres.', # MODIF
	'forum_ne_repondez_pas' => 'Nun responder a esti corréu sinón nel foru, nes señes darréu:',
	'forum_page_url' => '(Si el to mensaxe refierse a un artículu espublizáu na Rede, o a una páxina que tenga más información, equí embaxo vas poder indicar el títulu de la páxina y les sos señes.)',
	'forum_poste_par' => 'Mensaxe unviáu @parauteur@ tocante a l’artículu «@titre@».', # MODIF
	'forum_qui_etes_vous' => '<b>¿Quién yes?</b> (opcional)', # MODIF
	'forum_texte' => 'Testu del to mensaxe:', # MODIF
	'forum_titre' => 'Títulu',
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar la escoyeta',
	'forum_voir_avant' => 'Ver el mensaxe enantes de publicalu', # MODIF
	'forum_votre_email' => 'Les tos señes d’email:', # MODIF
	'forum_votre_nom' => 'El to nome (o nomatu):', # MODIF
	'forum_vous_enregistrer' => 'Pa poder participar nesti
  foru, primero hai que rexistrase.
  Escribe embaxo l’identificador personal que
  recibisti. Si nun tas rexistráu, ties que',
	'forum_vous_inscrire' => 'inscribite.',

	// I
	'icone_poster_message' => 'Unviar un mensaxe',
	'icone_suivi_forum' => 'Siguimientu del foru públicu: @nb_forums@ contribución(es)',
	'icone_suivi_forums' => 'Siguir/xestionar los foros',
	'icone_supprimer_message' => 'Desaniciar esti mensaxe',
	'icone_valider_message' => 'Validar esti mensaxe',
	'info_activer_forum_public' => '<i>Pa activar los foros públicos, has d’escoyer el tipu
 de moderación por omisión:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar esta escoyeta pal llendamientu:',
	'info_config_forums_prive' => 'Nel espaciu priváu del sitiu, puedes activar dellos tipos de foros:', # MODIF
	'info_config_forums_prive_admin' => 'Un foru acutáu pa los alministradores del sitiu:',
	'info_config_forums_prive_global' => 'Un foru global, abiertu pa tolos redactores:',
	'info_config_forums_prive_objets' => 'Un foru pa cada artículu, breve, sitiu referenciáu, etc.:',
	'info_desactiver_forum_public' => 'Desactivar l’usu de los foros publicos.
 Los foros públicos podrán autorizase casu por casu
 pa los artículos; pero tarán torgaos pa les estayes, breves, etc.',
	'info_envoi_forum' => 'Unvíu de los foros a los autores de los artículos',
	'info_fonctionnement_forum' => 'Funcionamientu del foru:',
	'info_gauche_suivi_forum_2' => 'La páxina de <i>siguimientu de los foros</i> ye una ferramienta de xestión del sitiu Web (y non un espaciu pal discutiniu o la redaición). Amuesa toles contribuciones de los foros del sitiu, lo mesmo de la parte pública que del espaciu priváu y te permite remanar eses contribuciones.', # MODIF
	'info_liens_syndiques_3' => 'foros',
	'info_liens_syndiques_4' => 'tan',
	'info_liens_syndiques_5' => 'foru',
	'info_liens_syndiques_6' => 'ta',
	'info_liens_syndiques_7' => 'esperando pola validación',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mou de funcionamientu por omisión de los foros públicos',
	'info_option_email' => 'Cuando un visitante del sitiu unvía un mensaxe nuevu al foru venceyáu a un artículu, puede avisase a los o les autores del mesmu por e-mail. Escoyer pa cada tipu de foru si va emplegase esta opción.',
	'info_pas_de_forum' => 'ensin foru',
	'info_question_visiteur_ajout_document_forum' => 'Si quiés autorizar que los visitantes amesten documentos (imáxenes, sones...) nos sos mensaxes del foru, indica embaxo la llista d’estensiones de documentu permitíes nos foros (p. ex: gif, jpg, png, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Si quiés autorizar tolos tipos de documentu que SPIP considera fiables, pon un asteriscu. Pa nun autorizar na, déxalo en blancu,', # MODIF
	'item_activer_forum_administrateur' => 'Activar el foru de los alministradores',
	'item_config_forums_prive_global' => 'Activar el foru de los redactores',
	'item_config_forums_prive_objets' => 'Activar estos foros',
	'item_desactiver_forum_administrateur' => 'Desactivar el foru de los alministradores',
	'item_non_config_forums_prive_global' => 'Desactivar el foru de los redactores',
	'item_non_config_forums_prive_objets' => 'Desactivar estos foros',

	// L
	'lien_reponse_article' => 'Respuesta a l’artículu',
	'lien_reponse_breve_2' => 'Respuesta a la breve',
	'lien_reponse_rubrique' => 'Respuesta a la estaya',
	'lien_reponse_site_reference' => 'Respuesta al sitiu referenciáu:', # MODIF

	// O
	'onglet_messages_internes' => 'Mensaxes internos',
	'onglet_messages_publics' => 'Mensaxes públicos',
	'onglet_messages_vide' => 'Mensaxes ensin testu',

	// R
	'repondre_message' => 'Responder a esti mensaxe',

	// S
	'statut_original' => 'orixinal',

	// T
	'text_article_propose_publication_forum' => 'Encamentamoste a dar la to opinión nel foru axuntu a esti artículu (embaxo de la páxina).',
	'texte_en_cours_validation_forum' => 'Encamentámoste que opines usando los foros que tien xuníos.',
	'titre_cadre_forum_administrateur' => 'Foru privau de los alministradores',
	'titre_cadre_forum_interne' => 'Foru internu',
	'titre_config_forums_prive' => 'Foros de l’espaciu priváu',
	'titre_forum' => 'Foru',
	'titre_forum_suivi' => 'Siguir foros',
	'titre_page_forum_suivi' => 'Siguir los foros',
];
